@@ -38,7 +38,7 @@ DEFAULT_TCP_USER_TIMEOUT_SECONDS = DEFAULT_TCP_KEEPALIVE_TIME + DEFAULT_TCP_KEEP
 DEFAULT_DISABLE_DUMP_LOAD = False
 DEFAULT_MAINTENANCE_TIMEOUT_MS = 50  # milliseconds
 DEFAULT_MAINTENANCE_PERIOD = 10  # seconds
-
+DEFAULT_LIVELOCK_ACQUIRE_TIMEOUT = 60 # seconds
 
 def get_settings(value, key, default):
     if value is not None:
@@ -147,3 +147,12 @@ def pack_resp(data):
         return _pack_bytes(data)
     else:
         raise Exception('Unsupported type %s' % str(t))
+
+class LazyArg(object):
+    __slots__ = ('action',)
+
+    def __init__(self, action):
+        self.action = action
+
+    def __str__(self):
+        return str(self.action())
\ No newline at end of file
